Box Anypoint&trade; Connector Demo - Files and Folder CRUD
==========================================================

## Introduction

The present demo application provides a **complete workflow** to sequentially invoke some of Box's **standard operations** against two of its many endpoints: **Files and Folders**.

## Prerequisites

* Java 7
* Anypoint Studio 5.4.x or higher
* Mule Runtime 3.7.x EE or higher
* DataWeave
* Access to a Box instance

## Import the project

* Go to **File > Import**
* Select **Anypoint Studio Project from External Location** (under the parent folder "Anypoint Studio")

    ![Import Menu](images/box-import-menu.png)

* Provide the root path to the demo project folder.
* Select Mule Runtime (3.7.x EE).

    ![File Selection](images/box-import-file.png)

* Click **Finish**.
* Set Box credentials inside the file `src/main/app/mule-app.properties`. This may vary depending on the selected connection configuration. The current demo uses **OAuth 2.0 Developer Token**:

    ```
    box.developerToken=<DEVELOPER_TOKEN>
    ```

* Open the **Global Element Configuration**.

    ![Global Element](images/box-connection-config.png)

* Click the **Test Connection** button to ensure there is connectivity with the sandbox. A successful message should pop-up.

    ![Test Connection](images/box-connection-test.png)

* Open a browser and access the URL **http://localhost:8081**. You should see the demo application deployed:

    ![Demo Index](images/box-main-page.png)

## About the flows

* **Upload_File_Flow:** adds a new file by specifying a file name and a destination folder ID.

    ![Flow Upload File](images/box-flow-file1.png)

* **Get_File_Flow:** retrieves the complete metadata of a file given its ID.

    ![Flow Get File](images/box-flow-file2.png)

* **Update_File_Flow:** uploads a new version of an existing file in a user account.

    ![Flow Update File](images/box-flow-file3.png)

* **Delete_File_Flow:** removes a file given its ID.

    ![Flow Delete File](images/box-flow-file4.png)

* **Create_Folder_Flow:** given a name, creates a new empty folder inside the specified parent folder.

    ![Flow Create Folder](images/box-flow-folder1.png)

* **Get_Folder_Flow:** retrieves the complete metadata of a folder given its ID.

    ![Flow Get Folder](images/box-flow-folder2.png)

* **Update_Folder_Flow:** updates the Name and Description of a folder given its ID.

    ![Flow Update Folder](images/box-flow-folder3.png)

+ **Delete_Folder_Flow:** removes a folder record given its ID. Recursion mode is configured by default.

    ![Flow Delete Folder](images/box-flow-folder4.png)

### Additional flows

* **Html_Form_Flow:** renders the HTML form.

    ![Flow HTML Form](images/box-flow-html.png)

* **Global_Exception_Strategy:** global exception strategy that handles all exceptions that may arise at runtime and forwards the error message to the HTML form.

    ![Exception Strategy Flow](images/box-flow-exception.png)

## Run the demo

### Upload File

![Demo Upload File](images/box-form-file1a.png)

* Click on the folder icon and select a file from your local directory.
* Provide a **Name** for the file.
* Provide the **ID of the parent folder** to upload to. Leave "0" for the root folder.
* Click the button **Upload** and wait a few moments to finish processing.
* If successfully created:
    * The file ID will be set in the rest of the forms and the next tab will be automatically activated.
    * You should see the file displayed in your Box account:

    ![Demo Upload File Box](images/box-form-file1b.png)

### Get File Info

![Demo Get File](images/box-form-file2a.png)

* Provide the **ID** of an existing file.
* Click the button **Get info** and wait a few moments to finish processing.
* If found, the metadata of the file will be displayed inside the **Result** textarea.

### Update File

![Demo Update File](images/box-form-file3a.png)

* Provide the **ID** of an existing file.
* Choose a new file to replace the older one.
* Click the button **Upload new version** and wait a few moments to finish processing.
* If successfully updated, in your Box account the modified file should be tagged with a version number such as V2, V3, V4, etc. See below:

    ![Demo Upload File Box](images/box-form-file3b.png)

### Delete File

![Demo Delete File](images/box-form-file4.png)

* Provide the **ID** of an existing file.
* Click the button **Delete** and wait a few moments to finish processing.

### Create Folder

![Demo Create Folder](images/box-form-folder1a.png)

* Provide a **Name** for the folder.
* Provide the **ID of the parent folder**. Leave "0" for the root folder.
* Click the button **Create** and wait a few moments to finish processing.
* If successfully created:
    * The folder ID will be set in the rest of the forms and the next tab will be automatically activated.
    * You should see the folder displayed in your Box account:

    ![Demo Upload Folder Box](images/box-form-folder1b.png)

### Get Folder Info

![Demo Get Folder](images/box-form-folder2.png)

* Provide an **ID** of an existing folder.
* Click the button **Get info** and wait a few moments to finish processing.
* If found, the metadata of the folder will be displayed inside the **Result** textarea.

### Update Folder

![Demo Update Folder](images/box-form-folder3a.png)

* Provide the **ID** of an existing folder.
* Provide new values for **Name** and **Description**.
* Click the button **Get info** and wait a few moments to finish processing.
* If successfully updated:
    * The metadata of the file will be displayed inside the **Result** textarea.
    * In your Box account, the modified folder should be displayed with different name and description:

        ![Demo Upload File Box](images/box-form-folder3b.png)

### Delete Folder

![Demo Delete Folder](images/box-form-folder4.png)

* Provide the **ID** of an existing folder.
* Click the button **Delete** and wait a few moments to finish processing.

## See more

* For additional technical information on the Box Connector, visit our [technical reference documentation](http://mulesoft.github.io/box-connector) or refer to the [Box Documentation Site](https://docs.mulesoft.com/mule-user-guide/v/3.8/box-connector).
* For more information on the Box API, go to the [Box API documentation page](https://docs.box.com/reference/).